Documentation
¶
Overview ¶
Package autoconfigure contributes the fallback tool only through an explicit blank import.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultTool ¶
DefaultTool constructs the fallback integer statistics bean.
func SpiceAutoConfiguration ¶
func SpiceAutoConfiguration() starter.AutoConfiguration
SpiceAutoConfiguration is statically decoded and is never executed during analysis.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.